pub struct Image { /* private fields */ }Expand description
An image that can receive values from the TIS-100. When in the Move mode, the image receives
coordinates that tell it where to draw. When in the Paint mode, the image will draw values.
Sending a negative value at any time will reset the image to Move mode.
Implementations