pub struct Line(pub usize, pub Option<Label>, pub Vec<String>);Expand description
A lexed source line, consisting of its line number, an optional label, and one or more lexemes that form an instruction.
Tuple Fields
0: usize1: Option<Label>2: Vec<String>Trait Implementations