Spec

Struct Spec 

pub struct Spec { /* private fields */ }
A specification for a TIS-100 puzzle. Specifications are Lua files that configure the layout, inputs, and outputs for the TIS-100. At a minimum, a specification must provide the get_layout and get_streams functions.

Implementations

Source

impl Spec

pub fn from_file(filename: &str, save: Save) -> Result<Spec, SpecError>

Load a Spec from a file.

pub fn setup(&mut self, cpu: &mut Tis100)

Configure a Tis100 instance using the spec.

pub fn tests(&self) -> VecMap<Box<dyn TestNode>>

Get the test output nodes used by the spec.